==> haskell-puremd5-2.1.3-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-96V59XsmtEG2bjOpQaFEJR
key: pureMD5-2.1.3-96V59XsmtEG2bjOpQaFEJR
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: 7f765acc267b0fe6cd22bbe6661c60be
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.4.3/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-96V59XsmtEG2bjOpQaFEJR
depends:
    base-4.11.1.0 bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.3-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-KK3rZpJq0YHHgUpKjSh8O1
key: pureMD5-2.1.3-KK3rZpJq0YHHgUpKjSh8O1
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: c7993d2d85741aeb64399e168f140b5b
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.4.3/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-KK3rZpJq0YHHgUpKjSh8O1
depends:
    base-4.11.1.0 bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=b38ee8fa4c1e132a024035423192fcff
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
